QuData - Qudas 0.1.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# QuData

量子データの形式を変換させるクラスです。

class qudas.qudata.QuData

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'qudas.qudata.qudata', 'input': <classmethod object>, 'output': <classmethod object>, '__dict__': <attribute '__dict__' of 'QuData' objects>, '__weakref__': <attribute '__weakref__' of 'QuData' objects>, '__doc__': None, '__annotations__': {}})
  __module__ = 'qudas.qudata.qudata'
  __weakref__

    list of weak references to the object (if defined)

  classmethod input(prob: Dict[str, Any] | None = None) → QuDataInput

    クラスメソッドとして QuDataInput のインスタンスを作成し、引数を受け取る。

    Parameters:

      prob (dict, optional) – QuDataInput の引数となる最適化問題データ。

    Returns:

      QuDataInput のインスタンス。

  classmethod output(result: Dict[str, Any] | None = None, result_type: str | None = None) → QuDataOutput

    クラスメソッドとして QuDataOutput のインスタンスを作成し、引数を受け取る。

    Parameters:

      - result (dict, optional) – QuDataOutput の引数となる計算結果データ。

      - result_type (str, optional) – 結果の形式。

    Returns:

      QuDataOutput のインスタンス。